# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15google/api/auth.proto\x12\ngoogle.api\x1a\x1cgoogle/api/annotations.proto\"l\n\x0e\x41uthentication\x12-\n\x05rules\x18\x03 \x03(\x0b\x32\x1e.google.api.AuthenticationRule\x12+\n\tproviders\x18\x04 \x03(\x0b\x32\x18.google.api.AuthProvider\"\xa9\x01\n\x12\x41uthenticationRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12,\n\x05oauth\x18\x02 \x01(\x0b\x32\x1d.google.api.OAuthRequirements\x12 \n\x18\x61llow_without_credential\x18\x05 \x01(\x08\x12\x31\n\x0crequirements\x18\x07 \x03(\x0b\x32\x1b.google.api.AuthRequirement\"j\n\x0c\x41uthProvider\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06issuer\x18\x02 \x01(\t\x12\x10\n\x08jwks_uri\x18\x03 \x01(\t\x12\x11\n\taudiences\x18\x04 \x01(\t\x12\x19\n\x11\x61uthorization_url\x18\x05 \x01(\t\"-\n\x11OAuthRequirements\x12\x18\n\x10\x63\x61nonical_scopes\x18\x01 \x01(\t\"9\n\x0f\x41uthRequirement\x12\x13\n\x0bprovider_id\x18\x01 \x01(\t\x12\x11\n\taudiences\x18\x02 \x01(\tBk\n\x0e\x63om.google.apiB\tAuthProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.auth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\tAuthProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\242\002\004GAPI'
  _AUTHENTICATION._serialized_start=67
  _AUTHENTICATION._serialized_end=175
  _AUTHENTICATIONRULE._serialized_start=178
  _AUTHENTICATIONRULE._serialized_end=347
  _AUTHPROVIDER._serialized_start=349
  _AUTHPROVIDER._serialized_end=455
  _OAUTHREQUIREMENTS._serialized_start=457
  _OAUTHREQUIREMENTS._serialized_end=502
  _AUTHREQUIREMENT._serialized_start=504
  _AUTHREQUIREMENT._serialized_end=561
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from api.v1 import ocellus_api_module_info_service_pb2 as api_dot_v1_dot_ocellus__api__module__info__service__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
import ocellus_types_pb2 as ocellus__types__pb2


class OcellusModuleInfoServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ReloadModules = channel.unary_unary(
                '/ocellus.api.v1.module.info.OcellusModuleInfoService/ReloadModules',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.GetModulesResponse.FromString,
                )
        self.UpdateModulesConfig = channel.unary_unary(
                '/ocellus.api.v1.module.info.OcellusModuleInfoService/UpdateModulesConfig',
                request_serializer=ocellus__types__pb2.GlobalConfig.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetModulesConfig = channel.unary_unary(
                '/ocellus.api.v1.module.info.OcellusModuleInfoService/GetModulesConfig',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ocellus__types__pb2.GlobalConfig.FromString,
                )
        self.GetModules = channel.unary_unary(
                '/ocellus.api.v1.module.info.OcellusModuleInfoService/GetModules',
                request_serializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.GetModulesRequest.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.GetModulesResponse.FromString,
                )
        self.CreateModule = channel.unary_unary(
                '/ocellus.api.v1.module.info.OcellusModuleInfoService/CreateModule',
                request_serializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.CreateModuleRequest.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.GetModulesResponse.FromString,
                )
        self.UpdateModule = channel.unary_unary(
                '/ocellus.api.v1.module.info.OcellusModuleInfoService/UpdateModule',
                request_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.PatchModule = channel.unary_unary(
                '/ocellus.api.v1.module.info.OcellusModuleInfoService/PatchModule',
                request_serializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.PatchModuleRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.DeleteModule = channel.unary_unary(
                '/ocellus.api.v1.module.info.OcellusModuleInfoService/DeleteModule',
                request_serializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.DeleteModuleRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateModuleOrder = channel.unary_unary(
                '/ocellus.api.v1.module.info.OcellusModuleInfoService/UpdateModuleOrder',
                request_serializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.UpdateModuleOrderRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ModuleApiHandler = channel.unary_unary(
                '/ocellus.api.v1.module.info.OcellusModuleInfoService/ModuleApiHandler',
                request_serializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.ModuleApiHandlerRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.GetRemoteModules = channel.unary_unary(
                '/ocellus.api.v1.module.info.OcellusModuleInfoService/GetRemoteModules',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.GetRemoteModulesResponse.FromString,
                )


class OcellusModuleInfoServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ReloadModules(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModulesConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModulesConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModules(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PatchModule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteModule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModuleOrder(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModuleApiHandler(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRemoteModules(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OcellusModuleInfoServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ReloadModules': grpc.unary_unary_rpc_method_handler(
                    servicer.ReloadModules,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.GetModulesResponse.SerializeToString,
            ),
            'UpdateModulesConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModulesConfig,
                    request_deserializer=ocellus__types__pb2.GlobalConfig.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetModulesConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModulesConfig,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ocellus__types__pb2.GlobalConfig.SerializeToString,
            ),
            'GetModules': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModules,
                    request_deserializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.GetModulesRequest.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.GetModulesResponse.SerializeToString,
            ),
            'CreateModule': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModule,
                    request_deserializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.CreateModuleRequest.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.GetModulesResponse.SerializeToString,
            ),
            'UpdateModule': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModule,
                    request_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'PatchModule': grpc.unary_unary_rpc_method_handler(
                    servicer.PatchModule,
                    request_deserializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.PatchModuleRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'DeleteModule': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteModule,
                    request_deserializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.DeleteModuleRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateModuleOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModuleOrder,
                    request_deserializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.UpdateModuleOrderRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ModuleApiHandler': grpc.unary_unary_rpc_method_handler(
                    servicer.ModuleApiHandler,
                    request_deserializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.ModuleApiHandlerRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'GetRemoteModules': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRemoteModules,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__module__info__service__pb2.GetRemoteModulesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ocellus.api.v1.module.info.OcellusModuleInfoService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OcellusModuleInfoService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ReloadModules(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.module.info.OcellusModuleInfoService/ReloadModules',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            api_dot_v1_dot_ocellus__api__module__info__service__pb2.GetModulesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateModulesConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.module.info.OcellusModuleInfoService/UpdateModulesConfig',
            ocellus__types__pb2.GlobalConfig.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModulesConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.module.info.OcellusModuleInfoService/GetModulesConfig',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ocellus__types__pb2.GlobalConfig.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModules(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.module.info.OcellusModuleInfoService/GetModules',
            api_dot_v1_dot_ocellus__api__module__info__service__pb2.GetModulesRequest.SerializeToString,
            api_dot_v1_dot_ocellus__api__module__info__service__pb2.GetModulesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.module.info.OcellusModuleInfoService/CreateModule',
            api_dot_v1_dot_ocellus__api__module__info__service__pb2.CreateModuleRequest.SerializeToString,
            api_dot_v1_dot_ocellus__api__module__info__service__pb2.GetModulesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateModule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.module.info.OcellusModuleInfoService/UpdateModule',
            google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PatchModule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.module.info.OcellusModuleInfoService/PatchModule',
            api_dot_v1_dot_ocellus__api__module__info__service__pb2.PatchModuleRequest.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteModule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.module.info.OcellusModuleInfoService/DeleteModule',
            api_dot_v1_dot_ocellus__api__module__info__service__pb2.DeleteModuleRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateModuleOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.module.info.OcellusModuleInfoService/UpdateModuleOrder',
            api_dot_v1_dot_ocellus__api__module__info__service__pb2.UpdateModuleOrderRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ModuleApiHandler(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.module.info.OcellusModuleInfoService/ModuleApiHandler',
            api_dot_v1_dot_ocellus__api__module__info__service__pb2.ModuleApiHandlerRequest.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRemoteModules(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.module.info.OcellusModuleInfoService/GetRemoteModules',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            api_dot_v1_dot_ocellus__api__module__info__service__pb2.GetRemoteModulesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ocellus_dataflow_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ocellus_types_pb2 as ocellus__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eocellus_dataflow_service.proto\x12\x07ocellus\x1a\x13ocellus_types.proto\"\'\n\x07Options\x12\x1c\n\x14sendPreDataflowEvent\x18\x01 \x01(\x08\"}\n\x06\x46ilter\x12\x18\n\x10pipelineIdFilter\x18\x01 \x03(\x03\x12\x16\n\x0eitemTypeFilter\x18\x02 \x03(\t\x12)\n\x0e\x64\x61taTypeFilter\x18\x03 \x03(\x0e\x32\x11.ocellus.DataType\x12\x16\n\x0emoduleIdFilter\x18\x04 \x03(\t\"]\n\x0b\x42indMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1f\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x0f.ocellus.Filter\x12!\n\x07options\x18\x03 \x01(\x0b\x32\x10.ocellus.Options\"\x12\n\x10PreDataflowEvent\",\n\rDataflowEvent\x12\x1b\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\r.ocellus.Data\"1\n\rDataflowError\x12\x10\n\x08moduleId\x18\x01 \x01(\t\x12\x0e\n\x06\x65rrors\x18\x02 \x03(\t\"<\n\x12\x44\x61taflowErrorEvent\x12&\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x16.ocellus.DataflowError\"\xfc\x01\n\x16\x44\x61taflowStreamingEvent\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x0f\n\x07\x66rameId\x18\x02 \x01(\x03\x12\x12\n\npipelineId\x18\x03 \x01(\x03\x12\x35\n\x10preDataflowEvent\x18\x04 \x01(\x0b\x32\x19.ocellus.PreDataflowEventH\x00\x12/\n\rdataflowEvent\x18\x05 \x01(\x0b\x32\x16.ocellus.DataflowEventH\x00\x12\x39\n\x12\x64\x61taflowErrorEvent\x18\x06 \x01(\x0b\x32\x1b.ocellus.DataflowErrorEventH\x00\x42\x07\n\x05\x65vent2\xa9\x01\n\x16OcellusDataflowService\x12\x46\n\tBindAsync\x12\x14.ocellus.BindMessage\x1a\x1f.ocellus.DataflowStreamingEvent\"\x00\x30\x01\x12G\n\x08\x42indSync\x12\x14.ocellus.BindMessage\x1a\x1f.ocellus.DataflowStreamingEvent\"\x00(\x01\x30\x01\x42u\n\x18ocellus.servers.dataflowB\x16OcellusDataflowServiceP\x01Z\x1egithub.com/byte-motion/ocellus\xa2\x02\x03OSD\xaa\x02\x18Ocellus.Servers.Dataflowb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ocellus_dataflow_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ocellus.servers.dataflowB\026OcellusDataflowServiceP\001Z\036github.com/byte-motion/ocellus\242\002\003OSD\252\002\030Ocellus.Servers.Dataflow'
  _OPTIONS._serialized_start=64
  _OPTIONS._serialized_end=103
  _FILTER._serialized_start=105
  _FILTER._serialized_end=230
  _BINDMESSAGE._serialized_start=232
  _BINDMESSAGE._serialized_end=325
  _PREDATAFLOWEVENT._serialized_start=327
  _PREDATAFLOWEVENT._serialized_end=345
  _DATAFLOWEVENT._serialized_start=347
  _DATAFLOWEVENT._serialized_end=391
  _DATAFLOWERROR._serialized_start=393
  _DATAFLOWERROR._serialized_end=442
  _DATAFLOWERROREVENT._serialized_start=444
  _DATAFLOWERROREVENT._serialized_end=504
  _DATAFLOWSTREAMINGEVENT._serialized_start=507
  _DATAFLOWSTREAMINGEVENT._serialized_end=759
  _OCELLUSDATAFLOWSERVICE._serialized_start=762
  _OCELLUSDATAFLOWSERVICE._serialized_end=931
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import ocellus_module_service_pb2 as ocellus__module__service__pb2


class OcellusModuleServiceStub(object):
    """*
    Service for remote modules
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Bind = channel.stream_stream(
                '/ocellus.OcellusModuleService/Bind',
                request_serializer=ocellus__module__service__pb2.ModuleData.SerializeToString,
                response_deserializer=ocellus__module__service__pb2.StateEvent.FromString,
                )
        self.DownloadRef = channel.unary_unary(
                '/ocellus.OcellusModuleService/DownloadRef',
                request_serializer=ocellus__module__service__pb2.DownloadRefRequest.SerializeToString,
                response_deserializer=ocellus__module__service__pb2.DownloadRefResponse.FromString,
                )


class OcellusModuleServiceServicer(object):
    """*
    Service for remote modules
    """

    def Bind(self, request_iterator, context):
        """*
        Used to bind a remote module to the Ocellus.
        Initial bind response will always receive an empty StateEvent
        containing only the initial frame id. This can be used in two ways:

        1. If the remote module is generating data for the rest of the
        pipeline it may begin. For example, it may begin sending images
        and pointclouds.

        2. If the remote module is processing data only, the data will
        begin to arrive in the next message.

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadRef(self, request, context):
        """*
        Used to download reference URNs provided by StateEvents.
        The data will only be available from after an event has
        been received and a response is sent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OcellusModuleServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Bind': grpc.stream_stream_rpc_method_handler(
                    servicer.Bind,
                    request_deserializer=ocellus__module__service__pb2.ModuleData.FromString,
                    response_serializer=ocellus__module__service__pb2.StateEvent.SerializeToString,
            ),
            'DownloadRef': grpc.unary_unary_rpc_method_handler(
                    servicer.DownloadRef,
                    request_deserializer=ocellus__module__service__pb2.DownloadRefRequest.FromString,
                    response_serializer=ocellus__module__service__pb2.DownloadRefResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ocellus.OcellusModuleService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OcellusModuleService(object):
    """*
    Service for remote modules
    """

    @staticmethod
    def Bind(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/ocellus.OcellusModuleService/Bind',
            ocellus__module__service__pb2.ModuleData.SerializeToString,
            ocellus__module__service__pb2.StateEvent.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DownloadRef(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.OcellusModuleService/DownloadRef',
            ocellus__module__service__pb2.DownloadRefRequest.SerializeToString,
            ocellus__module__service__pb2.DownloadRefResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ocellus_module_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ocellus_types_pb2 as ocellus__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cocellus_module_service.proto\x12\x07ocellus\x1a\x13ocellus_types.proto\"M\n\nStateEvent\x12\x1b\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\r.ocellus.Data\x12\x0f\n\x07\x66rameId\x18\x04 \x01(\x03\x12\x11\n\ttimestamp\x18\x05 \x01(\x03\";\n\x06IOData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x08\x64\x61taType\x18\x02 \x01(\x0e\x32\x11.ocellus.DataType\"f\n\x0b\x42indRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x06inputs\x18\x03 \x03(\x0b\x32\x0f.ocellus.IODataB\x02\x18\x01\x12$\n\x07outputs\x18\x04 \x03(\x0b\x32\x0f.ocellus.IODataB\x02\x18\x01\"\xa0\x03\n\nOutputData\x12\'\n\nintrinsics\x18\x01 \x01(\x0b\x32\x13.ocellus.Intrinsics\x12\"\n\x08\x63ontours\x18\x02 \x03(\x0b\x32\x10.ocellus.Contour\x12\x1f\n\x06\x63\x61mera\x18\x03 \x01(\x0b\x32\x0f.ocellus.Camera\x12(\n\x05image\x18\x04 \x01(\x0b\x32\x19.ocellus.OutputData.Image\x12\'\n\npointCloud\x18\x05 \x01(\x0b\x32\x13.ocellus.PointCloud\x12\x1c\n\x05items\x18\x06 \x03(\x0b\x32\r.ocellus.Item\x12\x0f\n\x07\x64\x65\x63imal\x18\x07 \x01(\x01\x12\x0f\n\x07integer\x18\x08 \x01(\x05\x12\x0e\n\x06string\x18\t \x01(\t\x12\x1e\n\x06\x65rrors\x18\n \x03(\x0b\x32\x0e.ocellus.Error\x12#\n\x08position\x18\x0b \x01(\x0b\x32\x11.ocellus.Position\x12%\n\x08rotation\x18\x0c \x01(\x0b\x32\x13.ocellus.Quaternion\x1a\x15\n\x05Image\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"|\n\nModuleData\x12+\n\x0b\x62indRequest\x18\x01 \x01(\x0b\x32\x14.ocellus.BindRequestH\x00\x12#\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x13.ocellus.OutputDataH\x00\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x42\t\n\x07payload\"!\n\x12\x44ownloadRefRequest\x12\x0b\n\x03urn\x18\x01 \x01(\t\"h\n\nPointCloud\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12%\n\x08vertices\x18\x03 \x03(\x0b\x32\x13.ocellus.Vector3Dim\x12\x14\n\x0cmat32FC1Data\x18\x04 \x01(\x0c\"[\n\x13\x44ownloadRefResponse\x12\x0e\n\x04\x64\x61ta\x18\x01 \x01(\x0cH\x00\x12)\n\npointCloud\x18\x02 \x01(\x0b\x32\x13.ocellus.PointCloudH\x00\x42\t\n\x07payload2\x9a\x01\n\x14OcellusModuleService\x12\x36\n\x04\x42ind\x12\x13.ocellus.ModuleData\x1a\x13.ocellus.StateEvent\"\x00(\x01\x30\x01\x12J\n\x0b\x44ownloadRef\x12\x1b.ocellus.DownloadRefRequest\x1a\x1c.ocellus.DownloadRefResponse\"\x00\x42o\n\x16ocellus.servers.moduleB\x14OcellusModuleServiceP\x01Z\x1egithub.com/byte-motion/ocellus\xa2\x02\x03OSM\xaa\x02\x16Ocellus.Servers.Moduleb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ocellus_module_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ocellus.servers.moduleB\024OcellusModuleServiceP\001Z\036github.com/byte-motion/ocellus\242\002\003OSM\252\002\026Ocellus.Servers.Module'
  _BINDREQUEST.fields_by_name['inputs']._options = None
  _BINDREQUEST.fields_by_name['inputs']._serialized_options = b'\030\001'
  _BINDREQUEST.fields_by_name['outputs']._options = None
  _BINDREQUEST.fields_by_name['outputs']._serialized_options = b'\030\001'
  _STATEEVENT._serialized_start=62
  _STATEEVENT._serialized_end=139
  _IODATA._serialized_start=141
  _IODATA._serialized_end=200
  _BINDREQUEST._serialized_start=202
  _BINDREQUEST._serialized_end=304
  _OUTPUTDATA._serialized_start=307
  _OUTPUTDATA._serialized_end=723
  _OUTPUTDATA_IMAGE._serialized_start=702
  _OUTPUTDATA_IMAGE._serialized_end=723
  _MODULEDATA._serialized_start=725
  _MODULEDATA._serialized_end=849
  _DOWNLOADREFREQUEST._serialized_start=851
  _DOWNLOADREFREQUEST._serialized_end=884
  _POINTCLOUD._serialized_start=886
  _POINTCLOUD._serialized_end=990
  _DOWNLOADREFRESPONSE._serialized_start=992
  _DOWNLOADREFRESPONSE._serialized_end=1083
  _OCELLUSMODULESERVICE._serialized_start=1086
  _OCELLUSMODULESERVICE._serialized_end=1240
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/v1/ocellus_api_module_info_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import ocellus_module_service_pb2 as ocellus__module__service__pb2
import ocellus_types_pb2 as ocellus__types__pb2
from protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,api/v1/ocellus_api_module_info_service.proto\x12\x1aocellus.api.v1.module.info\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cocellus_module_service.proto\x1a\x13ocellus_types.proto\x1a,protoc-gen-swagger/options/annotations.proto\"%\n\x11GetModulesRequest\x12\x10\n\x08moduleId\x18\x01 \x01(\t\"\xe4O\n\x12GetModulesResponse\x12(\n\x07modules\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct:\xa3O\x92\x41\x9fO2\x9cO\x12\x99O{\"modules\": [{\"inputParameters\": [],\"outputParameters\": [ {  \"name\": \"RGBA_IMAGE\",  \"dataType\": 4,  \"key\": \"\" }, {  \"name\": \"POINTCLOUD\",  \"dataType\": 5,  \"key\": \"\" }, {  \"name\": \"CAMERA\",  \"dataType\": 1,  \"key\": \"\" }],\"id\": \"rs1\",\"active\": true,\"render\": true,\"ordinal\": 0,\"pipeline\": 0,\"type\": \"RealSense\",\"moduleState\": 1,\"stateText\": \"\",\"rsCamera\": { \"processingBlocks\": {  \"alignEnabled\": true,  \"alignTo\": 2,  \"decimationFilterEnabled\": true,  \"streamFilter\": 1,  \"formatFilter\": 1,  \"filterMagnitude\": 8,  \"thresholdFilterEnabled\": false,  \"thresholdMaxDistance\": 1.5,  \"thresholdMinDistance\": 0,  \"disparityMode02\": 0,  \"spatialFilterEnabled\": false,  \"spatialMagnitude\": 1,  \"spatialSmoothAlpha\": 0.72000002861022949,  \"spatialSmoothDelta\": 9,  \"holeFillingMode\": 0,  \"temporalFilterEnabled\": false,  \"temporalSmoothAlpha\": 0.079999998211860657,  \"temporalSmoothDelta\": 100,  \"temporalPersistance\": 6,  \"holeFillingFilterEnabled\": false,  \"holesFill\": 2,  \"colorizerEnabled\": true,  \"visualPreset\": 0,  \"colorScheme\": 5,  \"histogramEqualization\": true,  \"colorizerMinDistance\": 0,  \"colorizerMaxDistance\": 6,  \"pointCloudEnabled\": true,  \"occlusionRemoval\": 2,  \"textureStream\": 1,  \"textureFormat\": 5 }, \"cameraInfo\": {  \"name\": \"\",  \"serialNumber\": \"\",  \"firmwareVersion\": \"\",  \"recommendedFirmwareVersion\": \"\",  \"physicalPort\": \"\",  \"debugOpCode\": \"\",  \"advancedMode\": \"\",  \"productId\": \"\",  \"cameraLocked\": \"\",  \"usbTypeDescriptor\": \"\" }, \"depthResolution\": {  \"width\": 0,  \"height\": 0 }, \"colorResolution\": {  \"width\": 0,  \"height\": 0 }, \"depthFps\": 2, \"colorFps\": 2, \"serialNumber\": \"\", \"mode\": 1, \"playbackFile\": \"/home/kcarlson/Documents/test/longredtape.bag\", \"availableFps\": [  6,  15,  30,  60 ], \"availableDepthResolutions\": [  {   \"devicePrefix\": \"D\",   \"resolutions\": [    {     \"width\": 424,     \"height\": 240    },    {     \"width\": 640,     \"height\": 360    },    {     \"width\": 640,     \"height\": 480    },    {     \"width\": 848,     \"height\": 100    },    {     \"width\": 848,     \"height\": 480    },    {     \"width\": 1280,     \"height\": 720    }   ]  },  {   \"devicePrefix\": \"L\",   \"resolutions\": [    {     \"width\": 240,     \"height\": 640    },    {     \"width\": 384,     \"height\": 1024    },    {     \"width\": 480,     \"height\": 640    },    {     \"width\": 640,     \"height\": 480    },    {     \"width\": 768,     \"height\": 1024    },    {     \"width\": 1024,     \"height\": 768    }   ]  } ], \"availableColorResolutions\": [  {   \"devicePrefix\": \"D\",   \"resolutions\": [    {     \"width\": 424,     \"height\": 240    },    {     \"width\": 640,     \"height\": 360    },    {     \"width\": 640,     \"height\": 480    },    {     \"width\": 848,     \"height\": 480    },    {     \"width\": 960,     \"height\": 540    },    {     \"width\": 1280,     \"height\": 720    }   ]  },  {   \"devicePrefix\": \"L\",   \"resolutions\": [    {     \"width\": 1280,     \"height\": 720    },    {     \"width\": 1920,     \"height\": 1080    }   ]  } ]},\"position\": { \"x\": 0.0052760359831154346, \"y\": 0.058778461068868637, \"z\": -0.00064044661121442914},\"orientation\": { \"x\": 5.0150761604309082, \"y\": 82.971817016601562, \"z\": 358.756103515625},\"showPointcloud\": false,\"depthImage\": false,\"imu\": false,\"errors\": []},{\"inputParameters\": [],\"outputParameters\": [ {  \"name\": \"RGBA_IMAGE\",  \"dataType\": 4,  \"key\": \"\" }, {  \"name\": \"CAMERA\",  \"dataType\": 1,  \"key\": \"\" }, {  \"name\": \"ITEMS\",  \"dataType\": 3,  \"key\": \"\" }, {  \"name\": \"POINTCLOUD\",  \"dataType\": 5,  \"key\": \"\" }],\"id\": \"img\",\"active\": true,\"render\": true,\"ordinal\": 1,\"pipeline\": 0,\"type\": \"ImageSource\",\"moduleState\": 0,\"stateText\": \"\",\"flipImage\": false,\"undistort\": false,\"contourThickness\": 1,\"path\": \"/home/kcarlson/Documents/test/slideshow\",\"displayTimeSeconds\": 5,\"intrinsicsConfigName\": \"\",\"position\": { \"x\": 0, \"y\": 0, \"z\": 0},\"orientation\": { \"x\": 0, \"y\": 0, \"z\": 0},\"itemProducerOptions\": { \"graphicType\": 0, \"showPointCloud\": false, \"surface2PolygonMeshOpts\": {  \"searchRadius\": 0.02500000037252903,  \"mu\": 2.5,  \"maximumNearestNeighbors\": 100,  \"maximumSurfaceAngle\": 45,  \"minimumAngle\": 10,  \"maximumAngle\": 120,  \"normalConsistency\": false,  \"consistentVertexOrdering\": true,  \"kSearch\": 20 }},\"errors\": []},{\"inputParameters\": [],\"outputParameters\": [ {  \"name\": \"RGBA_IMAGE\",  \"dataType\": 4,  \"key\": \"\" }, {  \"name\": \"POINTCLOUD\",  \"dataType\": 5,  \"key\": \"\" }, {  \"name\": \"CAMERA\",  \"dataType\": 1,  \"key\": \"\" }],\"id\": \"rs2\",\"active\": true,\"render\": true,\"ordinal\": 2,\"pipeline\": 1,\"type\": \"RealSense\",\"moduleState\": 1,\"stateText\": \"\",\"rsCamera\": { \"processingBlocks\": {  \"alignEnabled\": true,  \"alignTo\": 2,  \"decimationFilterEnabled\": true,  \"streamFilter\": 1,  \"formatFilter\": 1,  \"filterMagnitude\": 8,  \"thresholdFilterEnabled\": false,  \"thresholdMaxDistance\": 1.5,  \"thresholdMinDistance\": 0,  \"disparityMode02\": 0,  \"spatialFilterEnabled\": false,  \"spatialMagnitude\": 1,  \"spatialSmoothAlpha\": 0.72000002861022949,  \"spatialSmoothDelta\": 9,  \"holeFillingMode\": 0,  \"temporalFilterEnabled\": false,  \"temporalSmoothAlpha\": 0.079999998211860657,  \"temporalSmoothDelta\": 100,  \"temporalPersistance\": 6,  \"holeFillingFilterEnabled\": false,  \"holesFill\": 2,  \"colorizerEnabled\": true,  \"visualPreset\": 0,  \"colorScheme\": 5,  \"histogramEqualization\": true,  \"colorizerMinDistance\": 0,  \"colorizerMaxDistance\": 6,  \"pointCloudEnabled\": true,  \"occlusionRemoval\": 2,  \"textureStream\": 1,  \"textureFormat\": 5 }, \"cameraInfo\": {  \"name\": \"\",  \"serialNumber\": \"\",  \"firmwareVersion\": \"\",  \"recommendedFirmwareVersion\": \"\",  \"physicalPort\": \"\",  \"debugOpCode\": \"\",  \"advancedMode\": \"\",  \"productId\": \"\",  \"cameraLocked\": \"\",  \"usbTypeDescriptor\": \"\" }, \"depthResolution\": {  \"width\": 0,  \"height\": 0 }, \"colorResolution\": {  \"width\": 0,  \"height\": 0 }, \"depthFps\": 2, \"colorFps\": 2, \"serialNumber\": \"\", \"mode\": 1, \"playbackFile\": \"/home/kcarlson/Documents/test/longredtape.bag\", \"availableFps\": [  6,  15,  30,  60 ], \"availableDepthResolutions\": [  {   \"devicePrefix\": \"D\",   \"resolutions\": [    {     \"width\": 424,     \"height\": 240    },    {     \"width\": 640,     \"height\": 360    },    {     \"width\": 640,     \"height\": 480    },    {     \"width\": 848,     \"height\": 100    },    {     \"width\": 848,     \"height\": 480    },    {     \"width\": 1280,     \"height\": 720    }   ]  },  {   \"devicePrefix\": \"L\",   \"resolutions\": [    {     \"width\": 240,     \"height\": 640    },    {     \"width\": 384,     \"height\": 1024    },    {     \"width\": 480,     \"height\": 640    },    {     \"width\": 640,     \"height\": 480    },    {     \"width\": 768,     \"height\": 1024    },    {     \"width\": 1024,     \"height\": 768    }   ]  } ], \"availableColorResolutions\": [  {   \"devicePrefix\": \"D\",   \"resolutions\": [    {     \"width\": 424,     \"height\": 240    },    {     \"width\": 640,     \"height\": 360    },    {     \"width\": 640,     \"height\": 480    },    {     \"width\": 848,     \"height\": 480    },    {     \"width\": 960,     \"height\": 540    },    {     \"width\": 1280,     \"height\": 720    }   ]  },  {   \"devicePrefix\": \"L\",   \"resolutions\": [    {     \"width\": 1280,     \"height\": 720    },    {     \"width\": 1920,     \"height\": 1080    }   ]  } ]},\"position\": { \"x\": 0.0052760359831154346, \"y\": 0.058778461068868637, \"z\": -0.00064044661121442914},\"orientation\": { \"x\": 5.0150761604309082, \"y\": 82.971817016601562, \"z\": 358.756103515625},\"showPointcloud\": false,\"depthImage\": false,\"imu\": false,\"errors\": []},{\"inputParameters\": [],\"outputParameters\": [ {  \"name\": \"RGBA_IMAGE\",  \"dataType\": 4,  \"key\": \"\" }, {  \"name\": \"CAMERA\",  \"dataType\": 1,  \"key\": \"\" }, {  \"name\": \"ITEMS\",  \"dataType\": 3,  \"key\": \"\" }, {  \"name\": \"POINTCLOUD\",  \"dataType\": 5,  \"key\": \"\" }],\"id\": \"img2\",\"active\": true,\"render\": true,\"ordinal\": 3,\"pipeline\": 1,\"type\": \"ImageSource\",\"moduleState\": 0,\"stateText\": \"\",\"flipImage\": false,\"undistort\": false,\"contourThickness\": 1,\"path\": \"/home/kcarlson/Documents/test/slideshow\",\"displayTimeSeconds\": 5,\"intrinsicsConfigName\": \"\",\"position\": { \"x\": 0, \"y\": 0, \"z\": 0},\"orientation\": { \"x\": 0, \"y\": 0, \"z\": 0},\"itemProducerOptions\": { \"graphicType\": 0, \"showPointCloud\": false, \"surface2PolygonMeshOpts\": {  \"searchRadius\": 0.02500000037252903,  \"mu\": 2.5,  \"maximumNearestNeighbors\": 100,  \"maximumSurfaceAngle\": 45,  \"minimumAngle\": 10,  \"maximumAngle\": 120,  \"normalConsistency\": false,  \"consistentVertexOrdering\": true,  \"kSearch\": 20 }},\"errors\": []},{\"inputParameters\": [ {  \"name\": \"RGBA_IMAGE\",  \"dataType\": 4,  \"key\": \"rs1/RGBA_IMAGE\" }, {  \"name\": \"POINTCLOUD\",  \"dataType\": 5,  \"key\": \"rs1/POINTCLOUD\" }, {  \"name\": \"CAMERA\",  \"dataType\": 1,  \"key\": \"rs1/CAMERA\" }],\"outputParameters\": [ {  \"name\": \"CONTOURS\",  \"dataType\": 2,  \"key\": \"\" }, {  \"name\": \"RGBA_IMAGE\",  \"dataType\": 4,  \"key\": \"\" }, {  \"name\": \"ITEMS\",  \"dataType\": 3,  \"key\": \"\" }, {  \"name\": \"BLOB_COUNT\",  \"dataType\": 7,  \"key\": \"\" }],\"id\": \"blob1\",\"active\": true,\"render\": true,\"ordinal\": 4,\"pipeline\": 0,\"type\": \"Blob\",\"moduleState\": 0,\"stateText\": \"\",\"value0UpperBound\": 255,\"value0LowerBound\": 0,\"value1UpperBound\": 186,\"value1LowerBound\": 162,\"value2UpperBound\": 178,\"value2LowerBound\": 154,\"showRect\": false,\"rectColor\": { \"r\": 0, \"g\": 1, \"b\": 1, \"a\": 1},\"contourColor\": { \"r\": 0, \"g\": 0, \"b\": 1, \"a\": 1},\"contourThickness\": 1,\"trackerType\": 0,\"retrievalMode\": 0,\"colorPaletteType\": 0,\"invertMask\": false,\"dilateCount\": 0,\"blurAndReduceEnabled\": true,\"watershedEnabled\": false,\"erodeCount\": 0,\"erodeFirst\": false,\"minWidth\": 0,\"maxWidth\": 1,\"minHeight\": 0,\"maxHeight\": 1,\"kMeansCount\": 0,\"angleAnalysis\": 1,\"regionOfInterest\": { \"x\": 0, \"y\": 0, \"width\": 0, \"height\": 0},\"inferenceOnRoiImage\": false,\"extremePointsAnalysis\": 0,\"extremePointsDistanceFromCenterPoint\": 1,\"extremePointsFixedDistance\": 0,\"showRejected\": false,\"showRoi\": true,\"pointCloudFilters\": { \"holeFillingEnabled\": false, \"holeFillingResolution\": 1, \"holeFillingPasses\": 1},\"itemProducerOptions\": { \"graphicType\": 0, \"showPointCloud\": false, \"surface2PolygonMeshOpts\": {  \"searchRadius\": 0.02500000037252903,  \"mu\": 2.5,  \"maximumNearestNeighbors\": 100,  \"maximumSurfaceAngle\": 45,  \"minimumAngle\": 10,  \"maximumAngle\": 120,  \"normalConsistency\": false,  \"consistentVertexOrdering\": true,  \"kSearch\": 20 }},\"errors\": []}]}\"f\n\x13\x43reateModuleRequest\x12(\n\x07modules\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x15.ocellus.GlobalConfig\"\x9f\x02\n\x12PatchModuleRequest\x12\x10\n\x08moduleId\x18\x01 \x01(\t\x12L\n\noperations\x18\x02 \x03(\x0b\x32\x38.ocellus.api.v1.module.info.PatchModuleRequest.Operation\x1a\x34\n\tOperation\x12\n\n\x02op\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t:s\x92\x41p*#\n\nJSON Patch\x12\x15http://jsonpatch.com/2I\x12G{ \"operations\": [{ \"op\": \"replace\", \"path\": \"/baz\", \"value\": \"boo\" }] }\"M\n\x13\x44\x65leteModuleRequest\x12\x36\n\x08moduleId\x18\x01 \x01(\tB$\x92\x41!2\x14The module to delete\xd2\x01\x08moduleId\"\'\n\x18UpdateModuleOrderRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"v\n\x17ModuleApiHandlerRequest\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x10\n\x08moduleId\x18\x02 \x01(\t\x12\x11\n\tpathParam\x18\x03 \x01(\t\x12%\n\x04\x62ody\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xe7\x01\n\x18GetRemoteModulesResponse\x12V\n\x07modules\x18\x01 \x03(\x0b\x32\x45.ocellus.api.v1.module.info.GetRemoteModulesResponse.RemoteModuleInfo\x1as\n\x10RemoteModuleInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1f\n\x06inputs\x18\x02 \x03(\x0b\x32\x0f.ocellus.IOData\x12 \n\x07outputs\x18\x03 \x03(\x0b\x32\x0f.ocellus.IOData\x12\x0e\n\x06states\x18\x04 \x03(\t2\xfa\x12\n\x18OcellusModuleInfoService\x12\xb0\x01\n\rReloadModules\x12\x16.google.protobuf.Empty\x1a..ocellus.api.v1.module.info.GetModulesResponse\"W\x92\x41\x36\x1a\x34Will reload all modules from the configuration file.\x82\xd3\xe4\x93\x02\x18\x1a\x16/api/v1/modules/reload\x12\x9b\x01\n\x13UpdateModulesConfig\x12\x15.ocellus.GlobalConfig\x1a\x16.google.protobuf.Empty\"U\x92\x41\x34\x1a\x32Updates the global configuration, does not persist\x82\xd3\xe4\x93\x02\x18\x1a\x16/api/v1/modules/config\x12\x90\x01\n\x10GetModulesConfig\x12\x16.google.protobuf.Empty\x1a\x15.ocellus.GlobalConfig\"M\x92\x41,\x1a*Retreives the current global configuration\x82\xd3\xe4\x93\x02\x18\x12\x16/api/v1/modules/config\x12\xe4\x01\n\nGetModules\x12-.ocellus.api.v1.module.info.GetModulesRequest\x1a..ocellus.api.v1.module.info.GetModulesResponse\"w\x92\x41\x41\x1a?Returns all or the specified module\'s configuration information\x82\xd3\xe4\x93\x02-\x12\x19/api/v1/module/{moduleId}Z\x10\x12\x0e/api/v1/module\x12\xb2\x01\n\x0c\x43reateModule\x12/.ocellus.api.v1.module.info.CreateModuleRequest\x1a..ocellus.api.v1.module.info.GetModulesResponse\"A\x92\x41(\x1a&Creates a new module, does not persist\x82\xd3\xe4\x93\x02\x10\"\x0e/api/v1/module\x12\x89\x01\n\x0cUpdateModule\x12\x17.google.protobuf.Struct\x1a\x17.google.protobuf.Struct\"G\x92\x41.\x1a,Updates an existing module, does not persist\x82\xd3\xe4\x93\x02\x10\x1a\x0e/api/v1/module\x12\xaf\x02\n\x0bPatchModule\x12..ocellus.api.v1.module.info.PatchModuleRequest\x1a\x17.google.protobuf.Struct\"\xd6\x01\x92\x41\xae\x01\x1a\xab\x01Updates a specific field of an existing module, does not persist\nReplaces module fields with ops using jsonpatch. Only replace is supported\nReturns the updated module data\x82\xd3\xe4\x93\x02\x1e\x32\x19/api/v1/module/{moduleId}:\x01*\x12\xcb\x01\n\x0c\x44\x65leteModule\x12/.ocellus.api.v1.module.info.DeleteModuleRequest\x1a\x16.google.protobuf.Empty\"r\x92\x41<\x1a:Deletes a specific or all loaded modules, does not persist\x82\xd3\xe4\x93\x02-*\x19/api/v1/module/{moduleId}Z\x10*\x0e/api/v1/module\x12\xb8\x01\n\x11UpdateModuleOrder\x12\x34.ocellus.api.v1.module.info.UpdateModuleOrderRequest\x1a\x16.google.protobuf.Empty\"U\x92\x41\x36\x1a\x34\x43hanges the module execution order, does not persist\x82\xd3\xe4\x93\x02\x16\x1a\x14/api/v1/order/module\x12\xc2\x02\n\x10ModuleApiHandler\x12\x33.ocellus.api.v1.module.info.ModuleApiHandlerRequest\x1a\x17.google.protobuf.Struct\"\xdf\x01\x92\x41\x17\x1a\x15Module specific APIs.\x82\xd3\xe4\x93\x02\xbe\x01\x12,/api/{version}/module/{moduleId}/{pathParam}Z.*,/api/{version}/module/{moduleId}/{pathParam}Z.\",/api/{version}/module/{moduleId}/{pathParam}Z.\x1a,/api/{version}/module/{moduleId}/{pathParam}\x12\xed\x01\n\x10GetRemoteModules\x12\x16.google.protobuf.Empty\x1a\x34.ocellus.api.v1.module.info.GetRemoteModulesResponse\"\x8a\x01\x92\x41i\x1agReturns all the currently available remote modules connected using the ocellus.OcellusModuleService API\x82\xd3\xe4\x93\x02\x18\x12\x16/api/v1/modules/remote\x1a\x62\x92\x41_\x12]Service for interacting with the user configuration, module metadata, and module interactionsB\x81\x01\n\x1e\x63om.ocellus.api.v1.module.infoB\x18OcellusModuleInfoServiceP\x01Z\x1egithub.com/byte-motion/ocellus\xa2\x02\x05OAPMD\xaa\x02\x1aOcellus.Api.V1.Module.Infob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api.v1.ocellus_api_module_info_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.ocellus.api.v1.module.infoB\030OcellusModuleInfoServiceP\001Z\036github.com/byte-motion/ocellus\242\002\005OAPMD\252\002\032Ocellus.Api.V1.Module.Info'
  _GETMODULESRESPONSE._options = None
  _GETMODULESRESPONSE._serialized_options = b'\222A\237O2\234O\022\231O{\"modules\": [{\"inputParameters\": [],\"outputParameters\": [ {  \"name\": \"RGBA_IMAGE\",  \"dataType\": 4,  \"key\": \"\" }, {  \"name\": \"POINTCLOUD\",  \"dataType\": 5,  \"key\": \"\" }, {  \"name\": \"CAMERA\",  \"dataType\": 1,  \"key\": \"\" }],\"id\": \"rs1\",\"active\": true,\"render\": true,\"ordinal\": 0,\"pipeline\": 0,\"type\": \"RealSense\",\"moduleState\": 1,\"stateText\": \"\",\"rsCamera\": { \"processingBlocks\": {  \"alignEnabled\": true,  \"alignTo\": 2,  \"decimationFilterEnabled\": true,  \"streamFilter\": 1,  \"formatFilter\": 1,  \"filterMagnitude\": 8,  \"thresholdFilterEnabled\": false,  \"thresholdMaxDistance\": 1.5,  \"thresholdMinDistance\": 0,  \"disparityMode02\": 0,  \"spatialFilterEnabled\": false,  \"spatialMagnitude\": 1,  \"spatialSmoothAlpha\": 0.72000002861022949,  \"spatialSmoothDelta\": 9,  \"holeFillingMode\": 0,  \"temporalFilterEnabled\": false,  \"temporalSmoothAlpha\": 0.079999998211860657,  \"temporalSmoothDelta\": 100,  \"temporalPersistance\": 6,  \"holeFillingFilterEnabled\": false,  \"holesFill\": 2,  \"colorizerEnabled\": true,  \"visualPreset\": 0,  \"colorScheme\": 5,  \"histogramEqualization\": true,  \"colorizerMinDistance\": 0,  \"colorizerMaxDistance\": 6,  \"pointCloudEnabled\": true,  \"occlusionRemoval\": 2,  \"textureStream\": 1,  \"textureFormat\": 5 }, \"cameraInfo\": {  \"name\": \"\",  \"serialNumber\": \"\",  \"firmwareVersion\": \"\",  \"recommendedFirmwareVersion\": \"\",  \"physicalPort\": \"\",  \"debugOpCode\": \"\",  \"advancedMode\": \"\",  \"productId\": \"\",  \"cameraLocked\": \"\",  \"usbTypeDescriptor\": \"\" }, \"depthResolution\": {  \"width\": 0,  \"height\": 0 }, \"colorResolution\": {  \"width\": 0,  \"height\": 0 }, \"depthFps\": 2, \"colorFps\": 2, \"serialNumber\": \"\", \"mode\": 1, \"playbackFile\": \"/home/kcarlson/Documents/test/longredtape.bag\", \"availableFps\": [  6,  15,  30,  60 ], \"availableDepthResolutions\": [  {   \"devicePrefix\": \"D\",   \"resolutions\": [    {     \"width\": 424,     \"height\": 240    },    {     \"width\": 640,     \"height\": 360    },    {     \"width\": 640,     \"height\": 480    },    {     \"width\": 848,     \"height\": 100    },    {     \"width\": 848,     \"height\": 480    },    {     \"width\": 1280,     \"height\": 720    }   ]  },  {   \"devicePrefix\": \"L\",   \"resolutions\": [    {     \"width\": 240,     \"height\": 640    },    {     \"width\": 384,     \"height\": 1024    },    {     \"width\": 480,     \"height\": 640    },    {     \"width\": 640,     \"height\": 480    },    {     \"width\": 768,     \"height\": 1024    },    {     \"width\": 1024,     \"height\": 768    }   ]  } ], \"availableColorResolutions\": [  {   \"devicePrefix\": \"D\",   \"resolutions\": [    {     \"width\": 424,     \"height\": 240    },    {     \"width\": 640,     \"height\": 360    },    {     \"width\": 640,     \"height\": 480    },    {     \"width\": 848,     \"height\": 480    },    {     \"width\": 960,     \"height\": 540    },    {     \"width\": 1280,     \"height\": 720    }   ]  },  {   \"devicePrefix\": \"L\",   \"resolutions\": [    {     \"width\": 1280,     \"height\": 720    },    {     \"width\": 1920,     \"height\": 1080    }   ]  } ]},\"position\": { \"x\": 0.0052760359831154346, \"y\": 0.058778461068868637, \"z\": -0.00064044661121442914},\"orientation\": { \"x\": 5.0150761604309082, \"y\": 82.971817016601562, \"z\": 358.756103515625},\"showPointcloud\": false,\"depthImage\": false,\"imu\": false,\"errors\": []},{\"inputParameters\": [],\"outputParameters\": [ {  \"name\": \"RGBA_IMAGE\",  \"dataType\": 4,  \"key\": \"\" }, {  \"name\": \"CAMERA\",  \"dataType\": 1,  \"key\": \"\" }, {  \"name\": \"ITEMS\",  \"dataType\": 3,  \"key\": \"\" }, {  \"name\": \"POINTCLOUD\",  \"dataType\": 5,  \"key\": \"\" }],\"id\": \"img\",\"active\": true,\"render\": true,\"ordinal\": 1,\"pipeline\": 0,\"type\": \"ImageSource\",\"moduleState\": 0,\"stateText\": \"\",\"flipImage\": false,\"undistort\": false,\"contourThickness\": 1,\"path\": \"/home/kcarlson/Documents/test/slideshow\",\"displayTimeSeconds\": 5,\"intrinsicsConfigName\": \"\",\"position\": { \"x\": 0, \"y\": 0, \"z\": 0},\"orientation\": { \"x\": 0, \"y\": 0, \"z\": 0},\"itemProducerOptions\": { \"graphicType\": 0, \"showPointCloud\": false, \"surface2PolygonMeshOpts\": {  \"searchRadius\": 0.02500000037252903,  \"mu\": 2.5,  \"maximumNearestNeighbors\": 100,  \"maximumSurfaceAngle\": 45,  \"minimumAngle\": 10,  \"maximumAngle\": 120,  \"normalConsistency\": false,  \"consistentVertexOrdering\": true,  \"kSearch\": 20 }},\"errors\": []},{\"inputParameters\": [],\"outputParameters\": [ {  \"name\": \"RGBA_IMAGE\",  \"dataType\": 4,  \"key\": \"\" }, {  \"name\": \"POINTCLOUD\",  \"dataType\": 5,  \"key\": \"\" }, {  \"name\": \"CAMERA\",  \"dataType\": 1,  \"key\": \"\" }],\"id\": \"rs2\",\"active\": true,\"render\": true,\"ordinal\": 2,\"pipeline\": 1,\"type\": \"RealSense\",\"moduleState\": 1,\"stateText\": \"\",\"rsCamera\": { \"processingBlocks\": {  \"alignEnabled\": true,  \"alignTo\": 2,  \"decimationFilterEnabled\": true,  \"streamFilter\": 1,  \"formatFilter\": 1,  \"filterMagnitude\": 8,  \"thresholdFilterEnabled\": false,  \"thresholdMaxDistance\": 1.5,  \"thresholdMinDistance\": 0,  \"disparityMode02\": 0,  \"spatialFilterEnabled\": false,  \"spatialMagnitude\": 1,  \"spatialSmoothAlpha\": 0.72000002861022949,  \"spatialSmoothDelta\": 9,  \"holeFillingMode\": 0,  \"temporalFilterEnabled\": false,  \"temporalSmoothAlpha\": 0.079999998211860657,  \"temporalSmoothDelta\": 100,  \"temporalPersistance\": 6,  \"holeFillingFilterEnabled\": false,  \"holesFill\": 2,  \"colorizerEnabled\": true,  \"visualPreset\": 0,  \"colorScheme\": 5,  \"histogramEqualization\": true,  \"colorizerMinDistance\": 0,  \"colorizerMaxDistance\": 6,  \"pointCloudEnabled\": true,  \"occlusionRemoval\": 2,  \"textureStream\": 1,  \"textureFormat\": 5 }, \"cameraInfo\": {  \"name\": \"\",  \"serialNumber\": \"\",  \"firmwareVersion\": \"\",  \"recommendedFirmwareVersion\": \"\",  \"physicalPort\": \"\",  \"debugOpCode\": \"\",  \"advancedMode\": \"\",  \"productId\": \"\",  \"cameraLocked\": \"\",  \"usbTypeDescriptor\": \"\" }, \"depthResolution\": {  \"width\": 0,  \"height\": 0 }, \"colorResolution\": {  \"width\": 0,  \"height\": 0 }, \"depthFps\": 2, \"colorFps\": 2, \"serialNumber\": \"\", \"mode\": 1, \"playbackFile\": \"/home/kcarlson/Documents/test/longredtape.bag\", \"availableFps\": [  6,  15,  30,  60 ], \"availableDepthResolutions\": [  {   \"devicePrefix\": \"D\",   \"resolutions\": [    {     \"width\": 424,     \"height\": 240    },    {     \"width\": 640,     \"height\": 360    },    {     \"width\": 640,     \"height\": 480    },    {     \"width\": 848,     \"height\": 100    },    {     \"width\": 848,     \"height\": 480    },    {     \"width\": 1280,     \"height\": 720    }   ]  },  {   \"devicePrefix\": \"L\",   \"resolutions\": [    {     \"width\": 240,     \"height\": 640    },    {     \"width\": 384,     \"height\": 1024    },    {     \"width\": 480,     \"height\": 640    },    {     \"width\": 640,     \"height\": 480    },    {     \"width\": 768,     \"height\": 1024    },    {     \"width\": 1024,     \"height\": 768    }   ]  } ], \"availableColorResolutions\": [  {   \"devicePrefix\": \"D\",   \"resolutions\": [    {     \"width\": 424,     \"height\": 240    },    {     \"width\": 640,     \"height\": 360    },    {     \"width\": 640,     \"height\": 480    },    {     \"width\": 848,     \"height\": 480    },    {     \"width\": 960,     \"height\": 540    },    {     \"width\": 1280,     \"height\": 720    }   ]  },  {   \"devicePrefix\": \"L\",   \"resolutions\": [    {     \"width\": 1280,     \"height\": 720    },    {     \"width\": 1920,     \"height\": 1080    }   ]  } ]},\"position\": { \"x\": 0.0052760359831154346, \"y\": 0.058778461068868637, \"z\": -0.00064044661121442914},\"orientation\": { \"x\": 5.0150761604309082, \"y\": 82.971817016601562, \"z\": 358.756103515625},\"showPointcloud\": false,\"depthImage\": false,\"imu\": false,\"errors\": []},{\"inputParameters\": [],\"outputParameters\": [ {  \"name\": \"RGBA_IMAGE\",  \"dataType\": 4,  \"key\": \"\" }, {  \"name\": \"CAMERA\",  \"dataType\": 1,  \"key\": \"\" }, {  \"name\": \"ITEMS\",  \"dataType\": 3,  \"key\": \"\" }, {  \"name\": \"POINTCLOUD\",  \"dataType\": 5,  \"key\": \"\" }],\"id\": \"img2\",\"active\": true,\"render\": true,\"ordinal\": 3,\"pipeline\": 1,\"type\": \"ImageSource\",\"moduleState\": 0,\"stateText\": \"\",\"flipImage\": false,\"undistort\": false,\"contourThickness\": 1,\"path\": \"/home/kcarlson/Documents/test/slideshow\",\"displayTimeSeconds\": 5,\"intrinsicsConfigName\": \"\",\"position\": { \"x\": 0, \"y\": 0, \"z\": 0},\"orientation\": { \"x\": 0, \"y\": 0, \"z\": 0},\"itemProducerOptions\": { \"graphicType\": 0, \"showPointCloud\": false, \"surface2PolygonMeshOpts\": {  \"searchRadius\": 0.02500000037252903,  \"mu\": 2.5,  \"maximumNearestNeighbors\": 100,  \"maximumSurfaceAngle\": 45,  \"minimumAngle\": 10,  \"maximumAngle\": 120,  \"normalConsistency\": false,  \"consistentVertexOrdering\": true,  \"kSearch\": 20 }},\"errors\": []},{\"inputParameters\": [ {  \"name\": \"RGBA_IMAGE\",  \"dataType\": 4,  \"key\": \"rs1/RGBA_IMAGE\" }, {  \"name\": \"POINTCLOUD\",  \"dataType\": 5,  \"key\": \"rs1/POINTCLOUD\" }, {  \"name\": \"CAMERA\",  \"dataType\": 1,  \"key\": \"rs1/CAMERA\" }],\"outputParameters\": [ {  \"name\": \"CONTOURS\",  \"dataType\": 2,  \"key\": \"\" }, {  \"name\": \"RGBA_IMAGE\",  \"dataType\": 4,  \"key\": \"\" }, {  \"name\": \"ITEMS\",  \"dataType\": 3,  \"key\": \"\" }, {  \"name\": \"BLOB_COUNT\",  \"dataType\": 7,  \"key\": \"\" }],\"id\": \"blob1\",\"active\": true,\"render\": true,\"ordinal\": 4,\"pipeline\": 0,\"type\": \"Blob\",\"moduleState\": 0,\"stateText\": \"\",\"value0UpperBound\": 255,\"value0LowerBound\": 0,\"value1UpperBound\": 186,\"value1LowerBound\": 162,\"value2UpperBound\": 178,\"value2LowerBound\": 154,\"showRect\": false,\"rectColor\": { \"r\": 0, \"g\": 1, \"b\": 1, \"a\": 1},\"contourColor\": { \"r\": 0, \"g\": 0, \"b\": 1, \"a\": 1},\"contourThickness\": 1,\"trackerType\": 0,\"retrievalMode\": 0,\"colorPaletteType\": 0,\"invertMask\": false,\"dilateCount\": 0,\"blurAndReduceEnabled\": true,\"watershedEnabled\": false,\"erodeCount\": 0,\"erodeFirst\": false,\"minWidth\": 0,\"maxWidth\": 1,\"minHeight\": 0,\"maxHeight\": 1,\"kMeansCount\": 0,\"angleAnalysis\": 1,\"regionOfInterest\": { \"x\": 0, \"y\": 0, \"width\": 0, \"height\": 0},\"inferenceOnRoiImage\": false,\"extremePointsAnalysis\": 0,\"extremePointsDistanceFromCenterPoint\": 1,\"extremePointsFixedDistance\": 0,\"showRejected\": false,\"showRoi\": true,\"pointCloudFilters\": { \"holeFillingEnabled\": false, \"holeFillingResolution\": 1, \"holeFillingPasses\": 1},\"itemProducerOptions\": { \"graphicType\": 0, \"showPointCloud\": false, \"surface2PolygonMeshOpts\": {  \"searchRadius\": 0.02500000037252903,  \"mu\": 2.5,  \"maximumNearestNeighbors\": 100,  \"maximumSurfaceAngle\": 45,  \"minimumAngle\": 10,  \"maximumAngle\": 120,  \"normalConsistency\": false,  \"consistentVertexOrdering\": true,  \"kSearch\": 20 }},\"errors\": []}]}'
  _PATCHMODULEREQUEST._options = None
  _PATCHMODULEREQUEST._serialized_options = b'\222Ap*#\n\nJSON Patch\022\025http://jsonpatch.com/2I\022G{ \"operations\": [{ \"op\": \"replace\", \"path\": \"/baz\", \"value\": \"boo\" }] }'
  _DELETEMODULEREQUEST.fields_by_name['moduleId']._options = None
  _DELETEMODULEREQUEST.fields_by_name['moduleId']._serialized_options = b'\222A!2\024The module to delete\322\001\010moduleId'
  _OCELLUSMODULEINFOSERVICE._options = None
  _OCELLUSMODULEINFOSERVICE._serialized_options = b'\222A_\022]Service for interacting with the user configuration, module metadata, and module interactions'
  _OCELLUSMODULEINFOSERVICE.methods_by_name['ReloadModules']._options = None
  _OCELLUSMODULEINFOSERVICE.methods_by_name['ReloadModules']._serialized_options = b'\222A6\0324Will reload all modules from the configuration file.\202\323\344\223\002\030\032\026/api/v1/modules/reload'
  _OCELLUSMODULEINFOSERVICE.methods_by_name['UpdateModulesConfig']._options = None
  _OCELLUSMODULEINFOSERVICE.methods_by_name['UpdateModulesConfig']._serialized_options = b'\222A4\0322Updates the global configuration, does not persist\202\323\344\223\002\030\032\026/api/v1/modules/config'
  _OCELLUSMODULEINFOSERVICE.methods_by_name['GetModulesConfig']._options = None
  _OCELLUSMODULEINFOSERVICE.methods_by_name['GetModulesConfig']._serialized_options = b'\222A,\032*Retreives the current global configuration\202\323\344\223\002\030\022\026/api/v1/modules/config'
  _OCELLUSMODULEINFOSERVICE.methods_by_name['GetModules']._options = None
  _OCELLUSMODULEINFOSERVICE.methods_by_name['GetModules']._serialized_options = b'\222AA\032?Returns all or the specified module\'s configuration information\202\323\344\223\002-\022\031/api/v1/module/{moduleId}Z\020\022\016/api/v1/module'
  _OCELLUSMODULEINFOSERVICE.methods_by_name['CreateModule']._options = None
  _OCELLUSMODULEINFOSERVICE.methods_by_name['CreateModule']._serialized_options = b'\222A(\032&Creates a new module, does not persist\202\323\344\223\002\020\"\016/api/v1/module'
  _OCELLUSMODULEINFOSERVICE.methods_by_name['UpdateModule']._options = None
  _OCELLUSMODULEINFOSERVICE.methods_by_name['UpdateModule']._serialized_options = b'\222A.\032,Updates an existing module, does not persist\202\323\344\223\002\020\032\016/api/v1/module'
  _OCELLUSMODULEINFOSERVICE.methods_by_name['PatchModule']._options = None
  _OCELLUSMODULEINFOSERVICE.methods_by_name['PatchModule']._serialized_options = b'\222A\256\001\032\253\001Updates a specific field of an existing module, does not persist\nReplaces module fields with ops using jsonpatch. Only replace is supported\nReturns the updated module data\202\323\344\223\002\0362\031/api/v1/module/{moduleId}:\001*'
  _OCELLUSMODULEINFOSERVICE.methods_by_name['DeleteModule']._options = None
  _OCELLUSMODULEINFOSERVICE.methods_by_name['DeleteModule']._serialized_options = b'\222A<\032:Deletes a specific or all loaded modules, does not persist\202\323\344\223\002-*\031/api/v1/module/{moduleId}Z\020*\016/api/v1/module'
  _OCELLUSMODULEINFOSERVICE.methods_by_name['UpdateModuleOrder']._options = None
  _OCELLUSMODULEINFOSERVICE.methods_by_name['UpdateModuleOrder']._serialized_options = b'\222A6\0324Changes the module execution order, does not persist\202\323\344\223\002\026\032\024/api/v1/order/module'
  _OCELLUSMODULEINFOSERVICE.methods_by_name['ModuleApiHandler']._options = None
  _OCELLUSMODULEINFOSERVICE.methods_by_name['ModuleApiHandler']._serialized_options = b'\222A\027\032\025Module specific APIs.\202\323\344\223\002\276\001\022,/api/{version}/module/{moduleId}/{pathParam}Z.*,/api/{version}/module/{moduleId}/{pathParam}Z.\",/api/{version}/module/{moduleId}/{pathParam}Z.\032,/api/{version}/module/{moduleId}/{pathParam}'
  _OCELLUSMODULEINFOSERVICE.methods_by_name['GetRemoteModules']._options = None
  _OCELLUSMODULEINFOSERVICE.methods_by_name['GetRemoteModules']._serialized_options = b'\222Ai\032gReturns all the currently available remote modules connected using the ocellus.OcellusModuleService API\202\323\344\223\002\030\022\026/api/v1/modules/remote'
  _GETMODULESREQUEST._serialized_start=262
  _GETMODULESREQUEST._serialized_end=299
  _GETMODULESRESPONSE._serialized_start=302
  _GETMODULESRESPONSE._serialized_end=10514
  _CREATEMODULEREQUEST._serialized_start=10516
  _CREATEMODULEREQUEST._serialized_end=10618
  _PATCHMODULEREQUEST._serialized_start=10621
  _PATCHMODULEREQUEST._serialized_end=10908
  _PATCHMODULEREQUEST_OPERATION._serialized_start=10739
  _PATCHMODULEREQUEST_OPERATION._serialized_end=10791
  _DELETEMODULEREQUEST._serialized_start=10910
  _DELETEMODULEREQUEST._serialized_end=10987
  _UPDATEMODULEORDERREQUEST._serialized_start=10989
  _UPDATEMODULEORDERREQUEST._serialized_end=11028
  _MODULEAPIHANDLERREQUEST._serialized_start=11030
  _MODULEAPIHANDLERREQUEST._serialized_end=11148
  _GETREMOTEMODULESRESPONSE._serialized_start=11151
  _GETREMOTEMODULESRESPONSE._serialized_end=11382
  _GETREMOTEMODULESRESPONSE_REMOTEMODULEINFO._serialized_start=11267
  _GETREMOTEMODULESRESPONSE_REMOTEMODULEINFO._serialized_end=11382
  _OCELLUSMODULEINFOSERVICE._serialized_start=11385
  _OCELLUSMODULEINFOSERVICE._serialized_end=13811
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import ocellus_dataflow_service_pb2 as ocellus__dataflow__service__pb2


class OcellusDataflowServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BindAsync = channel.unary_stream(
                '/ocellus.OcellusDataflowService/BindAsync',
                request_serializer=ocellus__dataflow__service__pb2.BindMessage.SerializeToString,
                response_deserializer=ocellus__dataflow__service__pb2.DataflowStreamingEvent.FromString,
                )
        self.BindSync = channel.stream_stream(
                '/ocellus.OcellusDataflowService/BindSync',
                request_serializer=ocellus__dataflow__service__pb2.BindMessage.SerializeToString,
                response_deserializer=ocellus__dataflow__service__pb2.DataflowStreamingEvent.FromString,
                )


class OcellusDataflowServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def BindAsync(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BindSync(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OcellusDataflowServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BindAsync': grpc.unary_stream_rpc_method_handler(
                    servicer.BindAsync,
                    request_deserializer=ocellus__dataflow__service__pb2.BindMessage.FromString,
                    response_serializer=ocellus__dataflow__service__pb2.DataflowStreamingEvent.SerializeToString,
            ),
            'BindSync': grpc.stream_stream_rpc_method_handler(
                    servicer.BindSync,
                    request_deserializer=ocellus__dataflow__service__pb2.BindMessage.FromString,
                    response_serializer=ocellus__dataflow__service__pb2.DataflowStreamingEvent.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ocellus.OcellusDataflowService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OcellusDataflowService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def BindAsync(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ocellus.OcellusDataflowService/BindAsync',
            ocellus__dataflow__service__pb2.BindMessage.SerializeToString,
            ocellus__dataflow__service__pb2.DataflowStreamingEvent.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BindSync(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/ocellus.OcellusDataflowService/BindSync',
            ocellus__dataflow__service__pb2.BindMessage.SerializeToString,
            ocellus__dataflow__service__pb2.DataflowStreamingEvent.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/v1/ocellus_api_module_data_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,api/v1/ocellus_api_module_data_service.proto\x12\x1aocellus.api.v1.module.data\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,protoc-gen-swagger/options/annotations.proto\"\x91\x03\n\x14GetModuleDataRequest\x12Z\n\x08moduleId\x18\x01 \x01(\tBH\x92\x41\x45\x32\x43If provided, only data for the specified module id will be returned\x12\x66\n\x04path\x18\x02 \x01(\tBX\x92\x41U2SIf provided, it will only return the field which matches the path. Case insensitive\x12\xb4\x01\n\x04sort\x18\x03 \x01(\tB\xa5\x01\x92\x41\xa1\x01\x32\x9e\x01If provided, will sort according to query. Example: $.items[*].position.y:asc\nCurrently, only the follow ing supported:\n$.items[*].position.[x|y|z]:[asc|desc]\"\xca\x10\n\x12GetAllDataResponse\x12(\n\x07modules\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct:\x89\x10\x92\x41\x85\x10\x32\x82\x10\x12\xff\x0f{\"modules\": [{\"timestamp\": 3194,\"frameId\": 63,\"rgbaImage\": \"/img/rgbaImage\",\"camera\": { \"name\": \"rs1\", \"fov\": 58.165508270263672, \"position\": {\"x\": 0.0052760359831154346,\"y\": 0.058778464794158936,\"z\": -0.00064044661121442914 }, \"quaternion\": {\"w\": -0.74804270267486572,\"x\": -0.02558884397149086,\"y\": -0.66211831569671631,\"z\": 0.037104226648807526 }, \"orientation\": {\"pitch\": 5.0150761604309082,\"yaw\": 82.971817016601562,\"roll\": -1.243896484375 }}},{\"timestamp\": 3200,\"frameId\": 63,\"camera\": { \"name\": \"img\", \"fov\": 53.130104064941406, \"position\": {\"x\": 0,\"y\": 0,\"z\": 0 }, \"quaternion\": {\"w\": 1,\"x\": 0,\"y\": 0,\"z\": 0 }, \"orientation\": {\"pitch\": -0,\"yaw\": 0,\"roll\": 0 }},\"rgbaImage\": \"/img/rgbaImage\",\"items\": []},{\"timestamp\": 2792,\"frameId\": 96,\"camera\": { \"name\": \"rs2\", \"fov\": 58.165508270263672, \"position\": {\"x\": 0.0052760359831154346,\"y\": 0.058778464794158936,\"z\": -0.00064044661121442914 }, \"quaternion\": {\"w\": -0.74804270267486572,\"x\": -0.02558884397149086,\"y\": -0.66211831569671631,\"z\": 0.037104226648807526 }, \"orientation\": {\"pitch\": 5.0150761604309082,\"yaw\": 82.971817016601562,\"roll\": -1.243896484375 }},\"rgbaImage\": \"/img/rgbaImage\"},{\"timestamp\": 2792,\"frameId\": 96,\"items\": [],\"camera\": { \"name\": \"img2\", \"fov\": 53.130104064941406, \"position\": {\"x\": 0,\"y\": 0,\"z\": 0 }, \"quaternion\": {\"w\": 1,\"x\": 0,\"y\": 0,\"z\": 0 }, \"orientation\": {\"pitch\": -0,\"yaw\": 0,\"roll\": 0 }},\"rgbaImage\": \"/img/rgbaImage\"},{\"timestamp\": 3201,\"frameId\": 63,\"items\": [ {\"id\": 0,\"name\": \"blob1\",\"weight\": 0,\"confidence\": 1,\"color\": \"#0000FF\",\"dimension\": { \"width\": 0.044311594218015671, \"height\": 0.15963709354400635, \"depth\": 0.044311594218015671},\"position\": { \"x\": 0.28055679798126221, \"y\": 0.023770391941070557, \"z\": 0.038520518690347672},\"quaternion\": { \"w\": -0.018691437318921089, \"x\": 0.74761569499969482, \"y\": -0.044893074780702591, \"z\": -0.66234886646270752},\"orientation\": { \"pitch\": -5.01507568359375, \"yaw\": -97.0281982421875, \"roll\": -177.56260681152344},\"extremePoints\": {},\"pathPoints\": {},\"parentCamera\": \"rs1\" }],\"rgbaImage\": \"/img/rgbaImage\"}]}2\xb5\x03\n\x18OcellusModuleDataService\x12\xc3\x01\n\rGetModuleData\x12\x30.ocellus.api.v1.module.data.GetModuleDataRequest\x1a\x17.google.protobuf.Struct\"g\x92\x41-\x1a+Querys the data for the specified module id\x82\xd3\xe4\x93\x02\x31\x12\x12/api/v1/{moduleId}Z\x1b\x12\x19/api/v1/{moduleId}/{path}\x12\xac\x01\n\nGetAllData\x12\x30.ocellus.api.v1.module.data.GetModuleDataRequest\x1a..ocellus.api.v1.module.data.GetAllDataResponse\"<\x92\x41*\x1a(Returns all data produced by all modules\x82\xd3\xe4\x93\x02\t\x12\x07/api/v1\x1a$\x92\x41!\x12\x1fServes data produced by modulesB\x81\x01\n\x1e\x63om.ocellus.api.v1.module.dataB\x18OcellusModuleDataServiceP\x01Z\x1egithub.com/byte-motion/ocellus\xa2\x02\x05OAPMD\xaa\x02\x1aOcellus.Api.V1.Module.Datab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api.v1.ocellus_api_module_data_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.ocellus.api.v1.module.dataB\030OcellusModuleDataServiceP\001Z\036github.com/byte-motion/ocellus\242\002\005OAPMD\252\002\032Ocellus.Api.V1.Module.Data'
  _GETMODULEDATAREQUEST.fields_by_name['moduleId']._options = None
  _GETMODULEDATAREQUEST.fields_by_name['moduleId']._serialized_options = b'\222AE2CIf provided, only data for the specified module id will be returned'
  _GETMODULEDATAREQUEST.fields_by_name['path']._options = None
  _GETMODULEDATAREQUEST.fields_by_name['path']._serialized_options = b'\222AU2SIf provided, it will only return the field which matches the path. Case insensitive'
  _GETMODULEDATAREQUEST.fields_by_name['sort']._options = None
  _GETMODULEDATAREQUEST.fields_by_name['sort']._serialized_options = b'\222A\241\0012\236\001If provided, will sort according to query. Example: $.items[*].position.y:asc\nCurrently, only the follow ing supported:\n$.items[*].position.[x|y|z]:[asc|desc]'
  _GETALLDATARESPONSE._options = None
  _GETALLDATARESPONSE._serialized_options = b'\222A\205\0202\202\020\022\377\017{\"modules\": [{\"timestamp\": 3194,\"frameId\": 63,\"rgbaImage\": \"/img/rgbaImage\",\"camera\": { \"name\": \"rs1\", \"fov\": 58.165508270263672, \"position\": {\"x\": 0.0052760359831154346,\"y\": 0.058778464794158936,\"z\": -0.00064044661121442914 }, \"quaternion\": {\"w\": -0.74804270267486572,\"x\": -0.02558884397149086,\"y\": -0.66211831569671631,\"z\": 0.037104226648807526 }, \"orientation\": {\"pitch\": 5.0150761604309082,\"yaw\": 82.971817016601562,\"roll\": -1.243896484375 }}},{\"timestamp\": 3200,\"frameId\": 63,\"camera\": { \"name\": \"img\", \"fov\": 53.130104064941406, \"position\": {\"x\": 0,\"y\": 0,\"z\": 0 }, \"quaternion\": {\"w\": 1,\"x\": 0,\"y\": 0,\"z\": 0 }, \"orientation\": {\"pitch\": -0,\"yaw\": 0,\"roll\": 0 }},\"rgbaImage\": \"/img/rgbaImage\",\"items\": []},{\"timestamp\": 2792,\"frameId\": 96,\"camera\": { \"name\": \"rs2\", \"fov\": 58.165508270263672, \"position\": {\"x\": 0.0052760359831154346,\"y\": 0.058778464794158936,\"z\": -0.00064044661121442914 }, \"quaternion\": {\"w\": -0.74804270267486572,\"x\": -0.02558884397149086,\"y\": -0.66211831569671631,\"z\": 0.037104226648807526 }, \"orientation\": {\"pitch\": 5.0150761604309082,\"yaw\": 82.971817016601562,\"roll\": -1.243896484375 }},\"rgbaImage\": \"/img/rgbaImage\"},{\"timestamp\": 2792,\"frameId\": 96,\"items\": [],\"camera\": { \"name\": \"img2\", \"fov\": 53.130104064941406, \"position\": {\"x\": 0,\"y\": 0,\"z\": 0 }, \"quaternion\": {\"w\": 1,\"x\": 0,\"y\": 0,\"z\": 0 }, \"orientation\": {\"pitch\": -0,\"yaw\": 0,\"roll\": 0 }},\"rgbaImage\": \"/img/rgbaImage\"},{\"timestamp\": 3201,\"frameId\": 63,\"items\": [ {\"id\": 0,\"name\": \"blob1\",\"weight\": 0,\"confidence\": 1,\"color\": \"#0000FF\",\"dimension\": { \"width\": 0.044311594218015671, \"height\": 0.15963709354400635, \"depth\": 0.044311594218015671},\"position\": { \"x\": 0.28055679798126221, \"y\": 0.023770391941070557, \"z\": 0.038520518690347672},\"quaternion\": { \"w\": -0.018691437318921089, \"x\": 0.74761569499969482, \"y\": -0.044893074780702591, \"z\": -0.66234886646270752},\"orientation\": { \"pitch\": -5.01507568359375, \"yaw\": -97.0281982421875, \"roll\": -177.56260681152344},\"extremePoints\": {},\"pathPoints\": {},\"parentCamera\": \"rs1\" }],\"rgbaImage\": \"/img/rgbaImage\"}]}'
  _OCELLUSMODULEDATASERVICE._options = None
  _OCELLUSMODULEDATASERVICE._serialized_options = b'\222A!\022\037Serves data produced by modules'
  _OCELLUSMODULEDATASERVICE.methods_by_name['GetModuleData']._options = None
  _OCELLUSMODULEDATASERVICE.methods_by_name['GetModuleData']._serialized_options = b'\222A-\032+Querys the data for the specified module id\202\323\344\223\0021\022\022/api/v1/{moduleId}Z\033\022\031/api/v1/{moduleId}/{path}'
  _OCELLUSMODULEDATASERVICE.methods_by_name['GetAllData']._options = None
  _OCELLUSMODULEDATASERVICE.methods_by_name['GetAllData']._serialized_options = b'\222A*\032(Returns all data produced by all modules\202\323\344\223\002\t\022\007/api/v1'
  _GETMODULEDATAREQUEST._serialized_start=183
  _GETMODULEDATAREQUEST._serialized_end=584
  _GETALLDATARESPONSE._serialized_start=587
  _GETALLDATARESPONSE._serialized_end=2709
  _OCELLUSMODULEDATASERVICE._serialized_start=2712
  _OCELLUSMODULEDATASERVICE._serialized_end=3149
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/endpoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19google/api/endpoint.proto\x12\ngoogle.api\x1a\x1cgoogle/api/annotations.proto\"_\n\x08\x45ndpoint\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61liases\x18\x02 \x03(\t\x12\x10\n\x08\x66\x65\x61tures\x18\x04 \x03(\t\x12\x0e\n\x06target\x18\x65 \x01(\t\x12\x12\n\nallow_cors\x18\x05 \x01(\x08\x42o\n\x0e\x63om.google.apiB\rEndpointProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.endpoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\rEndpointProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\242\002\004GAPI'
  _ENDPOINT._serialized_start=71
  _ENDPOINT._serialized_end=166
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from api.v1 import ocellus_api_module_data_service_pb2 as api_dot_v1_dot_ocellus__api__module__data__service__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


class OcellusModuleDataServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetModuleData = channel.unary_unary(
                '/ocellus.api.v1.module.data.OcellusModuleDataService/GetModuleData',
                request_serializer=api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetModuleDataRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.GetAllData = channel.unary_unary(
                '/ocellus.api.v1.module.data.OcellusModuleDataService/GetAllData',
                request_serializer=api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetModuleDataRequest.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetAllDataResponse.FromString,
                )


class OcellusModuleDataServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetModuleData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OcellusModuleDataServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetModuleData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModuleData,
                    request_deserializer=api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetModuleDataRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'GetAllData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllData,
                    request_deserializer=api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetModuleDataRequest.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetAllDataResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ocellus.api.v1.module.data.OcellusModuleDataService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OcellusModuleDataService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetModuleData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.module.data.OcellusModuleDataService/GetModuleData',
            api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetModuleDataRequest.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.module.data.OcellusModuleDataService/GetAllData',
            api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetModuleDataRequest.SerializeToString,
            api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetAllDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/v1/ocellus_api_command_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(api/v1/ocellus_api_command_service.proto\x12\x16ocellus.api.v1.command\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a,protoc-gen-swagger/options/annotations.proto\"\x8f\x01\n\x17GetCameraCommandRequest\x12Y\n\x02id\x18\x01 \x01(\tBM\x92\x41J2CThe camera name to change the current camera in single monitor mode\xd2\x01\x02id:\x19\x92\x41\x16\x32\x14\x12\x12id=\"Editor Camera\"\"\x8a\x01\n\x1bGetScreenshotCommandRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61meras\x18\x02 \x03(\t:L\x92\x41I2G\x12\x45/api/v1/cmd/screenshot?path=test%2Fsubfulder&cameras=rs1&cameras=img1\"\x99\x02\n\x17GetRecordCommandRequest\x12L\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32<.ocellus.api.v1.command.GetRecordCommandRequest.RecordAction\x12r\n\x04path\x18\x02 \x01(\tBd\x92\x41\x61\x32XRelative path to the directory recording will be stored in from the ocellus media folder\xd2\x01\x04path\"<\n\x0cRecordAction\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05START\x10\x01\x12\x08\n\x04STOP\x10\x02\x12\n\n\x06STATUS\x10\x03\"%\n\x15GetLoadCommandRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\"\xc3\x01\n\x16GetPauseCommandRequest\x12X\n\x02id\x18\x01 \x01(\tBL\x92\x41I2GThe name of the module to pause. If absent, all modules will be paused.\x12O\n\x05query\x18\x02 \x01(\x08\x42@\x92\x41=2;If set, will return the modules which are currently paused.\"\x8c\x01\n\rRecordingFile\x12\x13\n\x0b\x65lapsedTime\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tthumbnail\x18\x03 \x01(\t\x12\x10\n\x08mimeType\x18\x04 \x01(\t\x12\x0c\n\x04size\x18\x05 \x01(\x03\x12\x13\n\x0bisDirectory\x18\x06 \x01(\x08\x12\x10\n\x08\x64\x61teTime\x18\x07 \x01(\t\"x\n\x16GetSaveCommandResponse\x12\x0c\n\x04name\x18\x01 \x01(\t:P\x92\x41M2K\x12I{\"name\": \"/home/ocellus/.config/unity3d/Byte Motion/Ocellus/default.ocl\"}\"P\n\x18GetRecordCommandResponse\x12\x34\n\x05\x66iles\x18\x01 \x03(\x0b\x32%.ocellus.api.v1.command.RecordingFile\"T\n\x1cGetScreenshotCommandResponse\x12\x34\n\x05\x66iles\x18\x01 \x03(\x0b\x32%.ocellus.api.v1.command.RecordingFile\"x\n\x16GetLoadCommandResponse\x12\x0c\n\x04name\x18\x01 \x01(\t:P\x92\x41M2K\x12I{\"name\": \"/home/ocellus/.config/unity3d/Byte Motion/Ocellus/default.ocl\"}\"\x89\x01\n\x18GetCameraCommandResponse\x12M\n\x02id\x18\x01 \x01(\tBA\x92\x41>27The name of the camera which was successfully chaged to\xd2\x01\x02id:\x1e\x92\x41\x1b\x32\x19\x12\x17{\"id\": \"Editor Camera\"}\"\x95\x01\n\x17GetPauseCommandResponse\x12K\n\x06states\x18\x01 \x03(\x0b\x32;.ocellus.api.v1.command.GetPauseCommandResponse.StatesEntry\x1a-\n\x0bStatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x32\xb3\x0c\n\x15OcellusCommandService\x12\xc3\x01\n\x10GetCameraCommand\x12/.ocellus.api.v1.command.GetCameraCommandRequest\x1a\x30.ocellus.api.v1.command.GetCameraCommandResponse\"L\x92\x41/\x1a-Sets the active camera in Single Monitor Mode\x82\xd3\xe4\x93\x02\x14\x12\x12/api/v1/cmd/camera\x12\xbc\x04\n\x14GetScreenshotCommand\x12\x33.ocellus.api.v1.command.GetScreenshotCommandRequest\x1a\x34.ocellus.api.v1.command.GetScreenshotCommandResponse\"\xb8\x03\x92\x41\x96\x03\x1a\x93\x03\x45xecutes screenshot command. This does all of the following:\n1) Takes a screenshot from all canvases in unity for all pipelines\n2) Creates PCD files for each generated pointcloud\n3) Dumps all current the outputs of each module to a respective OMD file\n4) If decorated screenshots have been enabled throught the OcellusConfigService.UpdateConfig rpc, wysiwyg screenshots for each canvas will be exported\n\x82\xd3\xe4\x93\x02\x18\x12\x16/api/v1/cmd/screenshot\x12\xae\x01\n\x10GetRecordCommand\x12/.ocellus.api.v1.command.GetRecordCommandRequest\x1a\x30.ocellus.api.v1.command.GetRecordCommandResponse\"7\x92\x41\x1a\x1a\x18Video recording commands\x82\xd3\xe4\x93\x02\x14\x12\x12/api/v1/cmd/record\x12\xa3\x01\n\x0eGetSaveCommand\x12\x16.google.protobuf.Empty\x1a..ocellus.api.v1.command.GetSaveCommandResponse\"I\x92\x41.\x1a,Saves the current user configuration to disk\x82\xd3\xe4\x93\x02\x12\x12\x10/api/v1/cmd/save\x12\xb1\x01\n\x0eGetLoadCommand\x12-.ocellus.api.v1.command.GetLoadCommandRequest\x1a..ocellus.api.v1.command.GetLoadCommandResponse\"@\x92\x41%\x1a#Restore to last saved configuration\x82\xd3\xe4\x93\x02\x12\x12\x10/api/v1/cmd/load\x12\xd0\x01\n\x0fGetPauseCommand\x12..ocellus.api.v1.command.GetPauseCommandRequest\x1a/.ocellus.api.v1.command.GetPauseCommandResponse\"\\\x92\x41@\x1a>Will pause execution of module(s) and freeze the current state\x82\xd3\xe4\x93\x02\x13\x12\x11/api/v1/cmd/pause\x1a\x37\x92\x41\x34\x12\x32\x41 collection of commands triggered by GET requestsBx\n\x1a\x63om.ocellus.api.v1.commandB\x15OcellusCommandServiceP\x01Z\x1egithub.com/byte-motion/ocellus\xa2\x02\x07OAPICMD\xaa\x02\x16Ocellus.Api.V1.Commandb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api.v1.ocellus_api_command_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.ocellus.api.v1.commandB\025OcellusCommandServiceP\001Z\036github.com/byte-motion/ocellus\242\002\007OAPICMD\252\002\026Ocellus.Api.V1.Command'
  _GETCAMERACOMMANDREQUEST.fields_by_name['id']._options = None
  _GETCAMERACOMMANDREQUEST.fields_by_name['id']._serialized_options = b'\222AJ2CThe camera name to change the current camera in single monitor mode\322\001\002id'
  _GETCAMERACOMMANDREQUEST._options = None
  _GETCAMERACOMMANDREQUEST._serialized_options = b'\222A\0262\024\022\022id=\"Editor Camera\"'
  _GETSCREENSHOTCOMMANDREQUEST._options = None
  _GETSCREENSHOTCOMMANDREQUEST._serialized_options = b'\222AI2G\022E/api/v1/cmd/screenshot?path=test%2Fsubfulder&cameras=rs1&cameras=img1'
  _GETRECORDCOMMANDREQUEST.fields_by_name['path']._options = None
  _GETRECORDCOMMANDREQUEST.fields_by_name['path']._serialized_options = b'\222Aa2XRelative path to the directory recording will be stored in from the ocellus media folder\322\001\004path'
  _GETPAUSECOMMANDREQUEST.fields_by_name['id']._options = None
  _GETPAUSECOMMANDREQUEST.fields_by_name['id']._serialized_options = b'\222AI2GThe name of the module to pause. If absent, all modules will be paused.'
  _GETPAUSECOMMANDREQUEST.fields_by_name['query']._options = None
  _GETPAUSECOMMANDREQUEST.fields_by_name['query']._serialized_options = b'\222A=2;If set, will return the modules which are currently paused.'
  _GETSAVECOMMANDRESPONSE._options = None
  _GETSAVECOMMANDRESPONSE._serialized_options = b'\222AM2K\022I{\"name\": \"/home/ocellus/.config/unity3d/Byte Motion/Ocellus/default.ocl\"}'
  _GETLOADCOMMANDRESPONSE._options = None
  _GETLOADCOMMANDRESPONSE._serialized_options = b'\222AM2K\022I{\"name\": \"/home/ocellus/.config/unity3d/Byte Motion/Ocellus/default.ocl\"}'
  _GETCAMERACOMMANDRESPONSE.fields_by_name['id']._options = None
  _GETCAMERACOMMANDRESPONSE.fields_by_name['id']._serialized_options = b'\222A>27The name of the camera which was successfully chaged to\322\001\002id'
  _GETCAMERACOMMANDRESPONSE._options = None
  _GETCAMERACOMMANDRESPONSE._serialized_options = b'\222A\0332\031\022\027{\"id\": \"Editor Camera\"}'
  _GETPAUSECOMMANDRESPONSE_STATESENTRY._options = None
  _GETPAUSECOMMANDRESPONSE_STATESENTRY._serialized_options = b'8\001'
  _OCELLUSCOMMANDSERVICE._options = None
  _OCELLUSCOMMANDSERVICE._serialized_options = b'\222A4\0222A collection of commands triggered by GET requests'
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetCameraCommand']._options = None
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetCameraCommand']._serialized_options = b'\222A/\032-Sets the active camera in Single Monitor Mode\202\323\344\223\002\024\022\022/api/v1/cmd/camera'
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetScreenshotCommand']._options = None
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetScreenshotCommand']._serialized_options = b'\222A\226\003\032\223\003Executes screenshot command. This does all of the following:\n1) Takes a screenshot from all canvases in unity for all pipelines\n2) Creates PCD files for each generated pointcloud\n3) Dumps all current the outputs of each module to a respective OMD file\n4) If decorated screenshots have been enabled throught the OcellusConfigService.UpdateConfig rpc, wysiwyg screenshots for each canvas will be exported\n\202\323\344\223\002\030\022\026/api/v1/cmd/screenshot'
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetRecordCommand']._options = None
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetRecordCommand']._serialized_options = b'\222A\032\032\030Video recording commands\202\323\344\223\002\024\022\022/api/v1/cmd/record'
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetSaveCommand']._options = None
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetSaveCommand']._serialized_options = b'\222A.\032,Saves the current user configuration to disk\202\323\344\223\002\022\022\020/api/v1/cmd/save'
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetLoadCommand']._options = None
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetLoadCommand']._serialized_options = b'\222A%\032#Restore to last saved configuration\202\323\344\223\002\022\022\020/api/v1/cmd/load'
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetPauseCommand']._options = None
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetPauseCommand']._serialized_options = b'\222A@\032>Will pause execution of module(s) and freeze the current state\202\323\344\223\002\023\022\021/api/v1/cmd/pause'
  _GETCAMERACOMMANDREQUEST._serialized_start=174
  _GETCAMERACOMMANDREQUEST._serialized_end=317
  _GETSCREENSHOTCOMMANDREQUEST._serialized_start=320
  _GETSCREENSHOTCOMMANDREQUEST._serialized_end=458
  _GETRECORDCOMMANDREQUEST._serialized_start=461
  _GETRECORDCOMMANDREQUEST._serialized_end=742
  _GETRECORDCOMMANDREQUEST_RECORDACTION._serialized_start=682
  _GETRECORDCOMMANDREQUEST_RECORDACTION._serialized_end=742
  _GETLOADCOMMANDREQUEST._serialized_start=744
  _GETLOADCOMMANDREQUEST._serialized_end=781
  _GETPAUSECOMMANDREQUEST._serialized_start=784
  _GETPAUSECOMMANDREQUEST._serialized_end=979
  _RECORDINGFILE._serialized_start=982
  _RECORDINGFILE._serialized_end=1122
  _GETSAVECOMMANDRESPONSE._serialized_start=1124
  _GETSAVECOMMANDRESPONSE._serialized_end=1244
  _GETRECORDCOMMANDRESPONSE._serialized_start=1246
  _GETRECORDCOMMANDRESPONSE._serialized_end=1326
  _GETSCREENSHOTCOMMANDRESPONSE._serialized_start=1328
  _GETSCREENSHOTCOMMANDRESPONSE._serialized_end=1412
  _GETLOADCOMMANDRESPONSE._serialized_start=1414
  _GETLOADCOMMANDRESPONSE._serialized_end=1534
  _GETCAMERACOMMANDRESPONSE._serialized_start=1537
  _GETCAMERACOMMANDRESPONSE._serialized_end=1674
  _GETPAUSECOMMANDRESPONSE._serialized_start=1677
  _GETPAUSECOMMANDRESPONSE._serialized_end=1826
  _GETPAUSECOMMANDRESPONSE_STATESENTRY._serialized_start=1781
  _GETPAUSECOMMANDRESPONSE_STATESENTRY._serialized_end=1826
  _OCELLUSCOMMANDSERVICE._serialized_start=1829
  _OCELLUSCOMMANDSERVICE._serialized_end=3416
# @@protoc_insertion_point(module_scope)



# Copyright © 2022 Byte Motion AB
import sys
from os import path
  
# Adding the cwd to the path is needed since
# scripts generated from protos do not take the
# module name into consideration when importing.
cwd = path.abspath(path.dirname(__file__))
sys.path += [cwd]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/backend.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18google/api/backend.proto\x12\ngoogle.api\"1\n\x07\x42\x61\x63kend\x12&\n\x05rules\x18\x01 \x03(\x0b\x32\x17.google.api.BackendRule\"X\n\x0b\x42\x61\x63kendRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x10\n\x08\x64\x65\x61\x64line\x18\x03 \x01(\x01\x12\x14\n\x0cmin_deadline\x18\x04 \x01(\x01\x42n\n\x0e\x63om.google.apiB\x0c\x42\x61\x63kendProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.backend_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\014BackendProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\242\002\004GAPI'
  _BACKEND._serialized_start=40
  _BACKEND._serialized_end=89
  _BACKENDRULE._serialized_start=91
  _BACKENDRULE._serialized_end=179
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from api.v1 import ocellus_api_command_service_pb2 as api_dot_v1_dot_ocellus__api__command__service__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class OcellusCommandServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetCameraCommand = channel.unary_unary(
                '/ocellus.api.v1.command.OcellusCommandService/GetCameraCommand',
                request_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetCameraCommandRequest.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetCameraCommandResponse.FromString,
                )
        self.GetScreenshotCommand = channel.unary_unary(
                '/ocellus.api.v1.command.OcellusCommandService/GetScreenshotCommand',
                request_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetScreenshotCommandRequest.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetScreenshotCommandResponse.FromString,
                )
        self.GetRecordCommand = channel.unary_unary(
                '/ocellus.api.v1.command.OcellusCommandService/GetRecordCommand',
                request_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetRecordCommandRequest.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetRecordCommandResponse.FromString,
                )
        self.GetSaveCommand = channel.unary_unary(
                '/ocellus.api.v1.command.OcellusCommandService/GetSaveCommand',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetSaveCommandResponse.FromString,
                )
        self.GetLoadCommand = channel.unary_unary(
                '/ocellus.api.v1.command.OcellusCommandService/GetLoadCommand',
                request_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetLoadCommandRequest.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetLoadCommandResponse.FromString,
                )
        self.GetPauseCommand = channel.unary_unary(
                '/ocellus.api.v1.command.OcellusCommandService/GetPauseCommand',
                request_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetPauseCommandRequest.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetPauseCommandResponse.FromString,
                )


class OcellusCommandServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetCameraCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetScreenshotCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecordCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSaveCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLoadCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPauseCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OcellusCommandServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetCameraCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCameraCommand,
                    request_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetCameraCommandRequest.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetCameraCommandResponse.SerializeToString,
            ),
            'GetScreenshotCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.GetScreenshotCommand,
                    request_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetScreenshotCommandRequest.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetScreenshotCommandResponse.SerializeToString,
            ),
            'GetRecordCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRecordCommand,
                    request_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetRecordCommandRequest.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetRecordCommandResponse.SerializeToString,
            ),
            'GetSaveCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSaveCommand,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetSaveCommandResponse.SerializeToString,
            ),
            'GetLoadCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLoadCommand,
                    request_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetLoadCommandRequest.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetLoadCommandResponse.SerializeToString,
            ),
            'GetPauseCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPauseCommand,
                    request_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetPauseCommandRequest.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetPauseCommandResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ocellus.api.v1.command.OcellusCommandService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OcellusCommandService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetCameraCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.command.OcellusCommandService/GetCameraCommand',
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetCameraCommandRequest.SerializeToString,
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetCameraCommandResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetScreenshotCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.command.OcellusCommandService/GetScreenshotCommand',
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetScreenshotCommandRequest.SerializeToString,
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetScreenshotCommandResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRecordCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.command.OcellusCommandService/GetRecordCommand',
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetRecordCommandRequest.SerializeToString,
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetRecordCommandResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSaveCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.command.OcellusCommandService/GetSaveCommand',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetSaveCommandResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLoadCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.command.OcellusCommandService/GetLoadCommand',
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetLoadCommandRequest.SerializeToString,
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetLoadCommandResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPauseCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.command.OcellusCommandService/GetPauseCommand',
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetPauseCommandRequest.SerializeToString,
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetPauseCommandResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Always prefer setuptools over distutils
from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open
from os import path

# The directory containing this file
CWD = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(CWD, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

# This call to setup() does all the work
setup(
    name="ocellus",
    version="0.1.19",
    description="Ocellus API Python Client",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://docs.ocellus.io/",
    author="Byte Motion AB",
    author_email="python@bytemotion.se",
    license="MIT",
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Operating System :: OS Independent"
    ],
    package_dir={"": "src"},
    packages=[
        'ocellus',
        'ocellus.api.v1',
        'ocellus.google.api',
        'ocellus.protoc_gen_swagger.options'
    ],
    include_package_data=True,
    install_requires=[
        "grpcio == 1.43.0",
        "protobuf == 3.19.3"
    ]
)